unit MainCal;

interface

uses Classes, Controls, Forms, StdCtrls, Spin;

type
  TMainCalForm = class(TForm)
    EventsLB: TListBox;
    EventAddBtn: TButton;
    EventEditBtn: TButton;
    EventDeleteBtn: TButton;
    GroupBox2: TGroupBox;
    StoreBtn: TButton;
    Label5: TLabel;
    Label1: TLabel;
    Label2: TLabel;
    Label6: TLabel;
    Label7: TLabel;
    ConnectBtn: TButton;
    CheckBox1: TCheckBox;
    ProxyEd: TEdit;
    PortEd: TSpinEdit;
    UserNameEd: TEdit;
    PasswordEd: TEdit;
    ServerEd: TEdit;
    DSEd: TEdit;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure ConnectBtnClick(Sender: TObject);
    procedure EventsLBClick(Sender: TObject);
    procedure EventAddBtnClick(Sender: TObject);
    procedure EventEditBtnClick(Sender: TObject);
    procedure EventDeleteBtnClick(Sender: TObject);
    procedure StoreBtnClick(Sender: TObject);
    procedure CheckBox1Click(Sender: TObject);
  private
    procedure UpdateEvents;
    procedure UpdateEventButtons;
  end;

var
  MainCalForm: TMainCalForm;

implementation

uses SysUtils, EditEvent, CalSyncML, SyncMLBase;

{$R *.dfm}

var
  SMLCalendar: TSMLCalendar;

procedure TMainCalForm.FormCreate(Sender: TObject);
begin
  SMLCalendar := TSMLCalendar.Create;
//  SMLCalendar.LogFileName := 'CalSyncML.log';
end;

procedure TMainCalForm.FormDestroy(Sender: TObject);
begin
  SMLCalendar.Free;
end;

procedure TMainCalForm.UpdateEvents;
var
  I: Integer;
begin
  EventsLB.Clear;
  Screen.Cursor := crHourGlass;
  try
    for I := 0 to SMLCalendar.EventsCount - 1 do
      with SMLCalendar.Events[I] do
        if LocalItemState <> isDeleted then
          EventsLB.Items.Add(Format('%s - %s  %s', [DateTimeToStr(StartTime), DateTimeToStr(EndTime), Title]));
  finally
    Screen.Cursor := crDefault;
  end;
  UpdateEventButtons;
end;

procedure TMainCalForm.UpdateEventButtons;
begin
  EventEditBtn.Enabled := EventsLB.ItemIndex >= 0;
  EventDeleteBtn.Enabled := EventsLB.ItemIndex >= 0;
end;

procedure TMainCalForm.ConnectBtnClick(Sender: TObject);
begin
  EventAddBtn.Enabled := False;
  EventsLB.Items.Clear;
  Application.ProcessMessages;
  if not CheckBox1.Checked then
  begin
    SMLCalendar.ProxyServer := ProxyEd.Text;
    SMLCalendar.ProxyPort := PortEd.Value;
  end
  else
  begin
    SMLCalendar.ProxyServer := '';
    SMLCalendar.ProxyPort := 0;
  end;
  SMLCalendar.BaseURL := ServerEd.Text;
  SMLCalendar.UserName := UserNameEd.Text;
  SMLCalendar.Password := PasswordEd.Text;
  SMLCalendar.DataSource := DSEd.Text;
  SMLCalendar.Load;
  EventAddBtn.Enabled := True;
  UpdateEvents;
  ConnectBtn.Caption := 'Refresh';
  StoreBtn.Enabled := False;
  UpdateEventButtons;
end;

procedure TMainCalForm.EventsLBClick(Sender: TObject);
begin
  UpdateEventButtons;
end;

procedure TMainCalForm.EventAddBtnClick(Sender: TObject);
begin
  EditEventForm.Event := SMLCalendar.NewEvent;
  if EditEventForm.ShowModal = mrOK then
  begin
    EventsLB.Items.Add(Format('%s - %s  %s', [DateTimeToStr(EditEventForm.Event.StartTime),
      DateTimeToStr(EditEventForm.Event.EndTime), EditEventForm.Event.Title]));
    UpdateEventButtons;
    StoreBtn.Enabled := True;
  end
  else
    SMLCalendar.DeleteEvent(SMLCalendar.EventsCount - 1);
end;

procedure TMainCalForm.EventEditBtnClick(Sender: TObject);
begin
  EditEventForm.Event := SMLCalendar.Events[EventsLB.ItemIndex];
  if EditEventForm.ShowModal = mrOK then
  begin
    EventsLB.Items[EventsLB.ItemIndex] := Format('%s - %s  %s', [DateTimeToStr(EditEventForm.Event.StartTime),
      DateTimeToStr(EditEventForm.Event.EndTime), EditEventForm.Event.Title]);
    StoreBtn.Enabled := True;
  end;
end;

procedure TMainCalForm.EventDeleteBtnClick(Sender: TObject);
begin
  SMLCalendar.DeleteEvent(EventsLB.ItemIndex);
  EventsLB.Items.Delete(EventsLB.ItemIndex);
  UpdateEventButtons;
  StoreBtn.Enabled := True;
end;

procedure TMainCalForm.StoreBtnClick(Sender: TObject);
begin
  SMLCalendar.Store;
  UpdateEvents;
  StoreBtn.Enabled := false;
end;

procedure TMainCalForm.CheckBox1Click(Sender: TObject);
begin
  ProxyEd.Enabled := CheckBox1.Checked;
  PortEd.Enabled := ProxyEd.Enabled;
end;

end.

